@@ -79,7 +79,7 @@ GeomStrippedRows <- ggplot2::ggproto("GeomStrippedRows", ggplot2::Geom,
     ggplot2::GeomRect$draw_panel(
       data %>%
         dplyr::mutate(
-          y = plyr::round_any(.data$y, width),
+          y = round_any(.data$y, width),
           ymin = .data$y - width / 2 + nudge_y,
           ymax = .data$y + width / 2 + nudge_y,
           xmin = xfrom,
@@ -147,7 +147,7 @@ GeomStrippedCols <- ggplot2::ggproto("GeomStrippedCols", ggplot2::Geom,
     ggplot2::GeomRect$draw_panel(
       data %>%
         dplyr::mutate(
-          x = plyr::round_any(.data$x, width),
+          x = round_any(.data$x, width),
           xmin = .data$x - width / 2 + nudge_x,
           xmax = .data$x + width / 2 + nudge_x,
           ymin = yfrom,
