@@ -13,16 +13,18 @@
 #' `variable_labels` argument.
 #'
 #' @param data a data frame
-#' @param include variables to include, accept [tidy-select][dplyr::select]
+#' @param include variables to include, accepts [tidy-select][dplyr::select]
 #' syntax
 #' @param weights optional variable name of a weighting variable,
-#' accept [tidy-select][dplyr::select] syntax
+#' accepts [tidy-select][dplyr::select] syntax
 #' @param y name of the variable to be plotted on `y` axis (relevant when
 #' `.question` is mapped to "facets, see examples),
-#' accept [tidy-select][dplyr::select] syntax
+#' accepts [tidy-select][dplyr::select] syntax
 #' @param variable_labels a named list or a named vector of custom variable
 #' labels
-#' @param sort should variables be sorted?
+#' @param sort should the factor defined by `factor_to_sort` be sorted according
+#' to the answers (see `sort_method`)? One of "none" (default), "ascending" or
+#' "descending"
 #' @param sort_method method used to sort the variables: `"prop"` sort according
 #' to the proportion of answers higher than the centered level, `"mean"`
 #' considers answer as a score and sort according to the mean score, `"median"`
@@ -30,18 +32,27 @@
 #' @param sort_prop_include_center when sorting with `"prop"` and if the number
 #' of levels is uneven, should half of the central level be taken into account
 #' to compute the proportion?
+#' @param factor_to_sort name of the factor column to sort if `sort` is not
+#' equal to `"none"`; by default the list of questions passed to `include`;
+#' should be one factor column of the tibble returned by `gglikert_data()`;
+#' accepts [tidy-select][dplyr::select] syntax
 #' @param exclude_fill_values Vector of values that should not be displayed
 #' (but still taken into account for computing proportions),
 #' see [position_likert()]
+#' @param data_fun for advanced usage, custom function to be applied to the
+#' generated dataset at the end of `gglikert_data()`
 #' @param add_labels should percentage labels be added to the plot?
 #' @param labels_size size of the percentage labels
+#' @param labels_color color of the percentage labels (`"auto"` to use
+#' `hex_bw()` to determine a font color based on background color)
 #' @param labels_accuracy accuracy of the percentages, see
 #' [scales::label_percent()]
 #' @param labels_hide_below if provided, values below will be masked, see
 #' [label_percent_abs()]
 #' @param add_totals should the total proportions of negative and positive
 #' answers be added to plot? **This option is not compatible with facets!**
-#' @param totals_size size of total proportions
+#' @param totals_size size of the total proportions
+#' @param totals_color color of the total proportions
 #' @param totals_accuracy accuracy of the total proportions, see
 #' [scales::label_percent()]
 #' @param totals_fontface font face of the total proportions
@@ -138,6 +149,13 @@
 #' gglikert(df_group, q1:q6, facet_cols = vars(group))
 #'
 #' gglikert(df_group, q1:q6, y = "group", facet_rows = vars(.question))
+#'
+#' # Custom function to be applied on data
+#' f <- function(d) {
+#'   d$.question <- forcats::fct_relevel(d$.question, "q5", "q2")
+#'   d
+#' }
+#' gglikert(df, include = q1:q6, data_fun = f)
 #' }
 gglikert <- function(data,
                      include = dplyr::everything(),
@@ -147,13 +165,17 @@ gglikert <- function(data,
                      sort = c("none", "ascending", "descending"),
                      sort_method = c("prop", "mean", "median"),
                      sort_prop_include_center = totals_include_center,
+                     factor_to_sort = ".question",
                      exclude_fill_values = NULL,
+                     data_fun = NULL,
                      add_labels = TRUE,
                      labels_size = 3.5,
+                     labels_color = "auto",
                      labels_accuracy = 1,
                      labels_hide_below = .05,
                      add_totals = TRUE,
                      totals_size = labels_size,
+                     totals_color = "black",
                      totals_accuracy = labels_accuracy,
                      totals_fontface = "bold",
                      totals_include_center = FALSE,
@@ -174,7 +196,9 @@ gglikert <- function(data,
       sort = sort,
       sort_method = sort_method,
       sort_prop_include_center = sort_prop_include_center,
-      exclude_fill_values = exclude_fill_values
+      factor_to_sort = {{ factor_to_sort }},
+      exclude_fill_values = exclude_fill_values,
+      data_fun = data_fun
     )
 
   y <- broom.helpers::.select_to_varnames(
@@ -204,12 +228,33 @@ gglikert <- function(data,
         reverse = reverse_likert,
         exclude_fill_values = exclude_fill_values
       ),
-      stat = "prop",
+      stat = StatProp,
       complete = "fill",
       width = width
     )
 
-  if (add_labels) {
+  if (add_labels && labels_color == "auto") {
+    p <- p +
+      geom_text(
+        mapping = aes(
+          label = label_percent_abs(
+            hide_below = labels_hide_below,
+            accuracy = labels_accuracy
+          )(after_stat(prop)),
+          color = after_scale(hex_bw(.data$fill))
+        ),
+        stat = StatProp,
+        complete = "fill",
+        position = position_likert(
+          vjust = .5,
+          reverse = reverse_likert,
+          exclude_fill_values = exclude_fill_values
+        ),
+        size = labels_size
+      )
+  }
+
+  if (add_labels && labels_color != "auto") {
     p <- p +
       geom_text(
         mapping = aes(
@@ -218,14 +263,15 @@ gglikert <- function(data,
             accuracy = labels_accuracy
           )(after_stat(prop))
         ),
-        stat = "prop",
+        stat = StatProp,
         complete = "fill",
         position = position_likert(
           vjust = .5,
           reverse = reverse_likert,
           exclude_fill_values = exclude_fill_values
         ),
-        size = labels_size
+        size = labels_size,
+        color = labels_color
       )
   }
 
@@ -293,6 +339,7 @@ gglikert <- function(data,
         ),
         data = dtot,
         size = totals_size,
+        color = totals_color,
         fontface = totals_fontface
       )
   }
@@ -326,7 +373,9 @@ gglikert_data <- function(data,
                           sort = c("none", "ascending", "descending"),
                           sort_method = c("prop", "mean", "median"),
                           sort_prop_include_center = TRUE,
-                          exclude_fill_values = NULL) {
+                          factor_to_sort = ".question",
+                          exclude_fill_values = NULL,
+                          data_fun = NULL) {
   rlang::check_installed("broom.helpers")
   rlang::check_installed("labelled")
 
@@ -383,8 +432,15 @@ gglikert_data <- function(data,
   data$.question <- data_labels[data$.question] %>%
     forcats::fct_inorder()
 
+  factor_to_sort <- broom.helpers::.select_to_varnames(
+    select = {{ factor_to_sort }},
+    data = data,
+    arg_name = "factor_to_sort",
+    select_single = TRUE
+  )
+
   if (sort == "ascending" && sort_method == "prop") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -396,7 +452,7 @@ gglikert_data <- function(data,
       )
   }
   if (sort == "descending" && sort_method == "prop") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -408,7 +464,7 @@ gglikert_data <- function(data,
       )
   }
   if (sort == "ascending" && sort_method == "mean") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -419,7 +475,7 @@ gglikert_data <- function(data,
       )
   }
   if (sort == "descending" && sort_method == "mean") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -430,7 +486,7 @@ gglikert_data <- function(data,
       )
   }
   if (sort == "ascending" && sort_method == "median") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -441,7 +497,7 @@ gglikert_data <- function(data,
       )
   }
   if (sort == "descending" && sort_method == "median") {
-    data$.question <- data$.question %>%
+    data[[factor_to_sort]] <- data[[factor_to_sort]] %>%
       forcats::fct_reorder2(
         data$.answer,
         data$.weights,
@@ -452,6 +508,12 @@ gglikert_data <- function(data,
       )
   }
 
+  if (!is.null(data_fun)) {
+    if (!is.function(data_fun))
+      cli::cli_abort("{arg data_fun} should be a function.")
+    data <- data_fun(data)
+  }
+
   data
 }
 
@@ -537,8 +599,11 @@ gglikert_stacked <- function(data,
                              sort = c("none", "ascending", "descending"),
                              sort_method = c("prop", "mean", "median"),
                              sort_prop_include_center = FALSE,
+                             factor_to_sort = ".question",
+                             data_fun = NULL,
                              add_labels = TRUE,
                              labels_size = 3.5,
+                             labels_color = "auto",
                              labels_accuracy = 1,
                              labels_hide_below = .05,
                              add_median_line = FALSE,
@@ -555,7 +620,9 @@ gglikert_stacked <- function(data,
       sort = sort,
       sort_method = sort_method,
       sort_prop_include_center = sort_prop_include_center,
-      exclude_fill_values = NULL
+      factor_to_sort = {{ factor_to_sort }},
+      exclude_fill_values = NULL,
+      data_fun = data_fun
     )
 
   y <- broom.helpers::.select_to_varnames(
@@ -582,12 +649,32 @@ gglikert_stacked <- function(data,
     ) +
     geom_bar(
       position = position_fill(reverse = reverse_fill),
-      stat = "prop",
+      stat = StatProp,
       complete = "fill",
       width = width
     )
 
-  if (add_labels) {
+  if (add_labels && labels_color == "auto") {
+    p <- p +
+      geom_text(
+        mapping = aes(
+          label = label_percent_abs(
+            hide_below = labels_hide_below,
+            accuracy = labels_accuracy
+          )(after_stat(prop)),
+          color = after_scale(hex_bw(.data$fill))
+        ),
+        stat = StatProp,
+        complete = "fill",
+        position = position_fill(
+          vjust = .5,
+          reverse = reverse_fill
+        ),
+        size = labels_size
+      )
+  }
+
+  if (add_labels && labels_color != "auto") {
     p <- p +
       geom_text(
         mapping = aes(
@@ -596,13 +683,14 @@ gglikert_stacked <- function(data,
             accuracy = labels_accuracy
           )(after_stat(prop))
         ),
-        stat = "prop",
+        stat = StatProp,
         complete = "fill",
         position = position_fill(
           vjust = .5,
           reverse = reverse_fill
         ),
-        size = labels_size
+        size = labels_size,
+        color = labels_color
       )
   }
 
