@@ -1,4 +1,4 @@
-test_that("gglikert)", {
+test_that("gglikert()", {
   skip_on_cran()
   skip_if_not_installed("labelled")
   skip_if_not_installed("ggplot2")
@@ -138,6 +138,11 @@ test_that("gglikert)", {
     )
   )
 
+  vdiffr::expect_doppelganger(
+    "gglikert() colors",
+    gglikert(df, labels_color = "red", totals_color = "blue")
+  )
+
   vdiffr::expect_doppelganger(
     "gglikert() reverse",
     gglikert(df, y_reverse = TRUE, reverse_likert = TRUE)
@@ -170,6 +175,21 @@ test_that("gglikert)", {
     gglikert_stacked(df, add_median_line = TRUE)
   )
 
+  vdiffr::expect_doppelganger(
+    "gglikert_stacked() labels_color red",
+    gglikert_stacked(df, labels_color = "red")
+  )
+
+  vdiffr::expect_doppelganger(
+    "gglikert_stacked() labels_color auto",
+    gglikert_stacked(df, labels_color = "auto")
+  )
+
+  vdiffr::expect_doppelganger(
+    "gglikert_stacked() labels_color black",
+    gglikert_stacked(df, labels_color = "black")
+  )
+
   df_group <- df
   df_group$group1 <- sample(c("A", "B"), 150, replace = TRUE)
   df_group$group2 <- sample(c("a", "b", "c"), 150, replace = TRUE)
@@ -196,4 +216,21 @@ test_that("gglikert)", {
     "gglikert() facet_rows with group on y",
     gglikert(df_group, q1:q6, y = "group1", facet_rows = vars(.question))
   )
+
+  f <- function(d) {
+    d$.question <- forcats::fct_relevel(d$.question, "q5", "q2")
+    d
+  }
+  vdiffr::expect_doppelganger(
+    "gglikert() with data_fun",
+    gglikert(df_group, q1:q6, data_fun = f)
+  )
+  expect_error(gglikert(df_group, data_fun = "text"))
+})
+
+test_that("hex_bw()", {
+  expect_equal(hex_bw("#FFFFFF"), "#000000")
+  expect_equal(hex_bw("#BBBBBB"), "#000000")
+  expect_equal(hex_bw("#000000"), "#ffffff")
+  expect_equal(hex_bw("#444444"), "#ffffff")
 })
