@@ -13,6 +13,13 @@ test_that("stat_prop()", {
     p
   )
 
+  vdiffr::expect_doppelganger(
+    "stat_prop() direct call",
+    ggplot(d) +
+      aes(x = Class, fill = Survived, weight = Freq, by = Class) +
+      stat_prop(geom = "bar")
+  )
+
   vdiffr::expect_doppelganger(
     "stat_prop() titanic-facet",
     p + facet_grid(~Sex)
@@ -30,6 +37,17 @@ test_that("stat_prop()", {
       )
   )
 
+  vdiffr::expect_doppelganger(
+    "stat_prop() titanic-dodge (not specifying by)",
+    ggplot(d) +
+      aes(x = Class, fill = Survived, weight = Freq) +
+      geom_bar(position = "dodge") +
+      geom_text(
+        stat = "prop",
+        position = position_dodge(0.9), vjust = "bottom"
+      )
+  )
+
   vdiffr::expect_doppelganger(
     "stat_prop() titanic-stack",
     ggplot(d) +
